@@ -15,7 +15,7 @@ Ext.define('Ux.locale.override.extjs.Panel', {
 
     setLocale : function(locale) {        
         var me          = this,
-            locales     = me.locales,
+            locales     = me.localesWin ? me.localesWin : me.locales,
             title       = locales.title,
             manager     = me.locale,
             defaultText = '',
